==> phpicalendar-2.1p0.tgz: phpicalendar/languages/brazilian.inc.php <==
<?php

// Brazilian Portuguese language include
// For version 1.0 PHP iCalendar
//
// Translation by Wilton, Bennet (suporte@bennetworks.com.br) 
// 01-nov-2002 02:42 PM
// Submit new translations to chad@chadsdomain.com

$lang['l_day']				= 'Dia';
$lang['l_week']				= 'Semana';
$lang['l_month']			= 'M&ecirc;s';
$lang['l_year']				= 'Ano';
$lang['l_calendar']         = 'Calend&aacute;rio';
$lang['l_next_day']         = 'Dia seguinte';
$lang['l_next_month']       = 'M&ecirc;s seguinte';
$lang['l_next_week']        = 'Pr&oacute;xima semana';
$lang['l_next_year']        = 'Ano Seguinte';
$lang['l_last_day']         = 'Dia anterior';
$lang['l_last_month']       = 'M&ecirc;s anterior';
$lang['l_last_week']        = 'Semana anterior';
$lang['l_last_year']        = 'Ano anterior';
$lang['l_subscribe']        = 'Assinar';
$lang['l_download']         = 'Download';
$lang['l_powered_by']       = 'Powered by';
$lang['l_event']            = 'Evento';
$lang['l_event_start']      = 'Hora de in&iacute;cio';
$lang['l_event_end']        = 'Hora de fim';
$lang['l_this_months']      = 'Eventos deste m&ecirc;s';
$lang['l_date']             = 'Data';
$lang['l_summary']          = 'Sum&aacute;rio';
$lang['l_all_day']          = 'Evento dia todo';
$lang['l_notes']            = 'Notas';
$lang['l_this_years']       = 'Eventos deste ano';
$lang['l_today']            = 'Hoje';
$lang['l_this_week']        = 'Esta semana';
$lang['l_this_month']       = 'Este m&ecirc;s';
$lang['l_jump']             = 'Ir para';
$lang['l_tomorrows']        = 'Eventos para amanha';
$lang['l_goday']            = 'Ir para Hoje';
$lang['l_goweek']           = 'Ir para este semana';
$lang['l_gomonth']          = 'Ir para este m&ecirc;s';
$lang['l_goyear']           = 'Ir para este ano';
$lang['l_search']			= 'Buscar'; // the verb
$lang['l_results']			= 'Buscar Resultados';
$lang['l_query']			= 'Quest&atilde;o: '; // will be followed by the search query
$lang['l_no_results']		= 'Eventos n&atilde;o encontrados';
$lang['l_goprint']			= 'Vers&atilde;o para imprimir';
$lang['l_time']				= 'Hora';
$lang['l_summary']			= 'Resumo';
$lang['l_description']		= 'Descri&ccedil;&atilde;o';
$lang['l_this_site_is']		= 'Esse site &eacute;';
$lang['l_no_events_day']	= 'N&atilde;o h&aacute; eventos para hoje.';
$lang['l_no_events_week']	= 'N&atilde;o h&aacute; eventos para esta semana.';
$lang['l_no_events_month']	= 'N&atilde;o h&aacute; eventos para esse m&ecirc;s.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date']	= '%b %e';  // Lists just the day
$lang['l_rsslanguage']		= 'en-us';
$lang['l_search_took']		= 'Search took %s seconds';
$lang['l_recurring_event']	= 'Recurring event';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'No query given';
$lang['l_preferences']		= 'Preferences';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Select your default language:';
$lang['l_select_cal']		= 'Select your default calendar:';
$lang['l_select_view']		= 'Select your default view:';
$lang['l_select_time']		= 'Select your default start time:';
$lang['l_select_day']		= 'Select your default start day of week:';
$lang['l_select_style']		= 'Select your default style:';
$lang['l_set_prefs']		= 'Set preferences';
$lang['l_completed_date']	= 'Completed on';
$lang['l_completed']		= 'Completed';
$lang['l_created']			= 'Created:';
$lang['l_due']				= 'Due:';
$lang['l_priority']			= 'Priority:';
$lang['l_priority_high']	= 'High';
$lang['l_priority_low']		= 'Low';
$lang['l_priority_medium']	= 'Medium';
$lang['l_priority_none']	= 'None';
$lang['l_status']			= 'Status';
$lang['l_todo']				= 'To do items';
$lang['l_unfinished']		= 'Unfinished';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= 'Unset preferences:';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$lang['l_upload_error_gen']	= 'There was a problem with your upload.';
$lang['l_upload_error'][0]	= 'There was a problem with your upload.';
$lang['l_upload_error'][1]	= 'The file you are trying to upload is too big.';
$lang['l_upload_error'][2]	= 'The file you are trying to upload is too big.';
$lang['l_upload_error'][3]	= 'The file you are trying upload was only partially uploaded.';
$lang['l_upload_error'][4]	= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']		= 'Failed to copy file';
$lang['l_delete_error']		= 'Failed to delete file';
$lang['l_delete_success']	= 'was deleted successfully.';
$lang['l_action_success']	= 'Your action was successful.';
$lang['l_submit']			= 'Submit';
$lang['l_delete']			= 'Delete';
$all_cal_comb_lang			= 'All combined';

// New for 2.0
$lang['l_legend']			= 'Legend';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] = 'Back';
$lang['l_next'] = 'Next';
$lang['l_prev'] = 'Prev';
$lang['l_day_view'] = 'Day View';
$lang['l_week_view'] = 'Week View';
$lang['l_month_view'] = 'Month View';
$lang['l_year_view'] = 'Year View';

// ---------------------------------

// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('year','years');		// for these, put singular
$format_recur_lang['monthly']		= array('month','months');		// and plural forms
$format_recur_lang['weekly']		= array('week','weeks');		// these will be %freq%
$format_recur_lang['daily']			= array('day','days');			// in the replacement below
$format_recur_lang['hourly']		= array('hour','hours');
$format_recur_lang['minutely']		= array('minute','minutes');
$format_recur_lang['secondly']		= array('second','seconds');

$format_recur_lang['start']			= 'Every %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'until %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'for a count of %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In months: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'On dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'On days: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang                        = array ('Domingo','Segunda-Feira','Terca-Feira','Quarta-Feira','Quinta-Feira','Sexta-Feira','S&aacute;bado');
$daysofweekshort_lang                = array ('Dom','Seg','Ter','Qua','Qui','Sex','Sb');
$daysofweekreallyshort_lang        = array ('D','S','T','Q','Q','S','S');
$monthsofyear_lang                        = array ('Janeiro','Fevereiro','Maro','Abril','Maio','Junho','Julho','Agosto','Setembro','Outubro','Novembro','Dezembro');
$monthsofyearshort_lang                = array ('Jan','Fev','Mar','Abr','Mai','Jun','Jul','Ago','Set','Out','Nov','Dez');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A,%e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';

/*
Notes about dateFormat_*
        The pieces are similar to that of the PHP function strftime(),
        however only the following is supported at this time:

        %A - the full week day name as specified in $daysofweek_lang
        %a - the shortened week day name as specified in $daysofweekshort_lang
        %B - the full month name as specified in $monthsofyear_lang
        %b - the shortened month name as specified in $monthsofyearshort_lang
        %e - the day of the month as a decimal number (1 to 31)
        %Y - the 4-digit year

        If this causes problems with representing your language accurately, let
        us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] = 'Erro!';
$lang['l_error_window'] = 'Aconteceu um erro!';
$lang['l_error_calendar'] = 'O calend&aacute;rio "%s" estava sendo processado quando ocorreu este erro.';
$lang['l_error_path'] = 'N&atilde;o foi poss&iacute;vel abrir: "%s"';
$lang['l_error_back'] = 'Por favor use o bot&atilde;o de "Back" para voltar.';
$lang['l_error_remotecal'] = 'Este servidor bloqueia calend&aacute;rios remotos que nao foram aprovados.';
$lang['l_error_restrictedcal'] = 'Tentou acessar um calend&aacute;rio o qual &eacute; restrito o acesso neste servidor.';
$lang['l_error_invalidcal'] = 'Arquivo de calend&aacute;rio inv&aacute;lido. Por favor tente usar outro calend&aacute;rio.';

?>

==> phpicalendar-2.31p2.tgz: phpicalendar/languages/brazilian.inc.php <==
<?php

// Brazilian Portuguese language include
// For version 1.0 PHP iCalendar
//
// Translation by Wilton, Bennet (suporte@bennetworks.com.br) 
// 01-nov-2002 02:42 PM
// Submit new translations to chad@chadsdomain.com

$lang['l_day']				= 'Dia';
$lang['l_week']				= 'Semana';
$lang['l_month']			= 'M&ecirc;s';
$lang['l_year']				= 'Ano';
$lang['l_calendar']         = 'Calend&aacute;rio';
$lang['l_next_day']         = 'Dia seguinte';
$lang['l_next_month']       = 'M&ecirc;s seguinte';
$lang['l_next_week']        = 'Pr&oacute;xima semana';
$lang['l_next_year']        = 'Ano Seguinte';
$lang['l_last_day']         = 'Dia anterior';
$lang['l_last_month']       = 'M&ecirc;s anterior';
$lang['l_last_week']        = 'Semana anterior';
$lang['l_last_year']        = 'Ano anterior';
$lang['l_subscribe']        = 'Assinar';
$lang['l_download']         = 'Download';
$lang['l_powered_by']       = 'Powered by';
$lang['l_event']            = 'Evento';
$lang['l_event_start']      = 'Hora de in&iacute;cio';
$lang['l_event_end']        = 'Hora de fim';
$lang['l_this_months']      = 'Eventos deste m&ecirc;s';
$lang['l_date']             = 'Data';
$lang['l_summary']          = 'Sum&aacute;rio';
$lang['l_all_day']          = 'Evento dia todo';
$lang['l_notes']            = 'Notas';
$lang['l_this_years']       = 'Eventos deste ano';
$lang['l_today']            = 'Hoje';
$lang['l_this_week']        = 'Esta semana';
$lang['l_this_month']       = 'Este m&ecirc;s';
$lang['l_jump']             = 'Ir para';
$lang['l_tomorrows']        = 'Eventos para amanha';
$lang['l_goday']            = 'Ir para Hoje';
$lang['l_goweek']           = 'Ir para este semana';
$lang['l_gomonth']          = 'Ir para este m&ecirc;s';
$lang['l_goyear']           = 'Ir para este ano';
$lang['l_search']			= 'Buscar'; // the verb
$lang['l_results']			= 'Buscar Resultados';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query']			= 'Quest&atilde;o: '; // will be followed by the search query
$lang['l_no_results']		= 'Eventos n&atilde;o encontrados';
$lang['l_goprint']			= 'Vers&atilde;o para imprimir';
$lang['l_time']				= 'Hora';
$lang['l_summary']			= 'Resumo';
$lang['l_description']		= 'Descri&ccedil;&atilde;o';
$lang['l_this_site_is']		= 'Esse site &eacute;';
$lang['l_no_events_day']	= 'N&atilde;o h&aacute; eventos para hoje.';
$lang['l_no_events_week']	= 'N&atilde;o h&aacute; eventos para esta semana.';
$lang['l_no_events_month']	= 'N&atilde;o h&aacute; eventos para esse m&ecirc;s.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date']	= '%b %e';  // Lists just the day
$lang['l_rsslanguage']		= 'en-us';
$lang['l_search_took']		= 'Search took %s seconds';
$lang['l_recurring_event']	= 'Recurring event';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'No query given';
$lang['l_preferences']		= 'Preferences';
$lang['l_printer']			= 'Printer';
$lang['l_select_lang']		= 'Select your default language:';
$lang['l_select_cal']		= 'Select your default calendar:';
$lang['l_select_view']		= 'Select your default view:';
$lang['l_select_time']		= 'Select your default start time:';
$lang['l_select_day']		= 'Select your default start day of week:';
$lang['l_select_style']		= 'Select your default style:';
$lang['l_set_prefs']		= 'Set preferences';
$lang['l_completed_date']	= 'Completed on';
$lang['l_completed']		= 'Completed';
$lang['l_created']			= 'Created:';
$lang['l_due']				= 'Due:';
$lang['l_priority']			= 'Priority:';
$lang['l_priority_high']	= 'High';
$lang['l_priority_low']		= 'Low';
$lang['l_priority_medium']	= 'Medium';
$lang['l_priority_none']	= 'None';
$lang['l_status']			= 'Status';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'To do items';
$lang['l_unfinished']		= 'Unfinished';
$lang['l_prefs_set'] 		= 'Your preferences have been set.';
$lang['l_prefs_unset'] 		= 'Preferences unset. Changes will take place next page load.';
$lang['l_unset_prefs'] 		= 'Unset preferences:';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'PHP iCalendar Administration';
$lang['l_username']			= 'Username';
$lang['l_password']			= 'Password';
$lang['l_login']			= 'Login';
$lang['l_invalid_login']	= 'Wrong username or password.';
$lang['l_addupdate_cal']	= 'Add or Update a Calendar';
$lang['l_addupdate_desc']	= 'Add a calendar by uploading a new file. Update a calendar by uploading a file of the same name.';
$lang['l_delete_cal']		= 'Delete a Calendar';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Calendar File';
$lang['l_php_error']		= 'PHP Error';
$lang['l_upload_error_gen']	= 'There was a problem with your upload.';
$lang['l_upload_error'][0]	= 'There was a problem with your upload.';
$lang['l_upload_error'][1]	= 'The file you are trying to upload is too big.';
$lang['l_upload_error'][2]	= 'The file you are trying to upload is too big.';
$lang['l_upload_error'][3]	= 'The file you are trying upload was only partially uploaded.';
$lang['l_upload_error'][4]	= 'You must select a file for upload.';
$lang['l_upload_error_type'] = 'Only .ics files may be uploaded.';
$lang['l_copy_error']		= 'Failed to copy file';
$lang['l_delete_error']		= 'Failed to delete file';
$lang['l_delete_success']	= 'was deleted successfully.';
$lang['l_action_success']	= 'Your action was successful.';
$lang['l_submit']			= 'Submit';
$lang['l_delete']			= 'Delete';
$all_cal_comb_lang			= 'All combined';

// New for 2.0
$lang['l_legend']			= 'Legend';
$lang['l_admin_subhead']	= 'Manage your calendars from this page';
$lang['l_prefs_subhead']	= 'Sets a cookie for visiting this site';
$lang['l_rss_info']			= 'RSS Information';
$lang['l_rss_subhead']		= 'Basic RSS feeds available for each calendar';
$lang['l_rss_notenabled']	= 'RSS is not enabled on this site';

// - navigation
$lang['l_back'] = 'Back';
$lang['l_next'] = 'Next';
$lang['l_prev'] = 'Prev';
$lang['l_day_view'] = 'Day View';
$lang['l_week_view'] = 'Week View';
$lang['l_month_view'] = 'Month View';
$lang['l_year_view'] = 'Year View';

// ---------------------------------

// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('year','years');		// for these, put singular
$format_recur_lang['monthly']		= array('month','months');		// and plural forms
$format_recur_lang['weekly']		= array('week','weeks');		// these will be %freq%
$format_recur_lang['daily']			= array('day','days');			// in the replacement below
$format_recur_lang['hourly']		= array('hour','hours');
$format_recur_lang['minutely']		= array('minute','minutes');
$format_recur_lang['secondly']		= array('second','seconds');

$format_recur_lang['start']			= 'Every %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'until %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'for a count of %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'In months: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'On dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'On days: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang                        = array ('Domingo','Segunda-Feira','Terca-Feira','Quarta-Feira','Quinta-Feira','Sexta-Feira','S&aacute;bado');
$daysofweekshort_lang                = array ('Dom','Seg','Ter','Qua','Qui','Sex','Sb');
$daysofweekreallyshort_lang        = array ('D','S','T','Q','Q','S','S');
$monthsofyear_lang                        = array ('Janeiro','Fevereiro','Maro','Abril','Maio','Junho','Julho','Agosto','Setembro','Outubro','Novembro','Dezembro');
$monthsofyearshort_lang                = array ('Jan','Fev','Mar','Abr','Mai','Jun','Jul','Ago','Set','Out','Nov','Dez');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'g:i A';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A,%e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a, %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A, %e %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
        The pieces are similar to that of the PHP function strftime(),
        however only the following is supported at this time:

        %A - the full week day name as specified in $daysofweek_lang
        %a - the shortened week day name as specified in $daysofweekshort_lang
        %B - the full month name as specified in $monthsofyear_lang
        %b - the shortened month name as specified in $monthsofyearshort_lang
        %e - the day of the month as a decimal number (1 to 31)
        %Y - the 4-digit year

        If this causes problems with representing your language accurately, let
        us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] = 'Erro!';
$lang['l_error_window'] = 'Aconteceu um erro!';
$lang['l_error_calendar'] = 'O calend&aacute;rio "%s" estava sendo processado quando ocorreu este erro.';
$lang['l_error_path'] = 'N&atilde;o foi poss&iacute;vel abrir: "%s"';
$lang['l_error_back'] = 'Por favor use o bot&atilde;o de "Back" para voltar.';
$lang['l_error_remotecal'] = 'Este servidor bloqueia calend&aacute;rios remotos que nao foram aprovados.';
$lang['l_error_restrictedcal'] = 'Tentou acessar um calend&aacute;rio o qual &eacute; restrito o acesso neste servidor.';
$lang['l_error_invalidcal'] = 'Arquivo de calend&aacute;rio inv&aacute;lido. Por favor tente usar outro calend&aacute;rio.';

?>
